betty.ancestry.name module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.name module

Data types to represent names.

final class betty.ancestry.name.Name

  Bases: `HasDate`

  A name.

  A name can be translated, and have a date expressing the period the name was in use.

  __init__(name: ShorthandStaticTranslations, *, date: Datey | None = None)
  name

    The name.